@@ -26,6 +26,7 @@ import os
 import platform
 import random
 import re
+import shlex
 import shutil
 import socket
 import string
@@ -59,8 +60,6 @@ from airflow.providers.google.common.hooks.base_google import (
     GoogleBaseHook,
     get_field,
 )
-from airflow.providers.mysql.hooks.mysql import MySqlHook
-from airflow.providers.postgres.hooks.postgres import PostgresHook
 from airflow.utils.log.logging_mixin import LoggingMixin
 
 if TYPE_CHECKING:
@@ -779,6 +778,8 @@ class CloudSQLDatabaseHook(BaseHook):
       SQL DB.
     * **use_ssl** - (default False) Whether SSL should be used to connect to Cloud SQL DB.
       You cannot use proxy and SSL together.
+    * **use_iam** - (default False) Whether IAM should be used to connect to Cloud SQL DB.
+      With using IAM password field should be empty string.
     * **sql_proxy_use_tcp** - (default False) If set to true, TCP is used to connect via
       proxy, otherwise UNIX sockets are used.
     * **sql_proxy_version** -  Specific version of the proxy to download (for example
@@ -841,11 +842,16 @@ class CloudSQLDatabaseHook(BaseHook):
         self.database_type = self.extras.get("database_type")
         self.use_proxy = self._get_bool(self.extras.get("use_proxy", "False"))
         self.use_ssl = self._get_bool(self.extras.get("use_ssl", "False"))
+        self.use_iam = self._get_bool(self.extras.get("use_iam", "False"))
         self.sql_proxy_use_tcp = self._get_bool(self.extras.get("sql_proxy_use_tcp", "False"))
         self.sql_proxy_version = self.extras.get("sql_proxy_version")
         self.sql_proxy_binary_path = sql_proxy_binary_path
-        self.user = self.cloudsql_connection.login
-        self.password = self.cloudsql_connection.password
+        if self.use_iam:
+            self.user = self._get_iam_db_login()
+            self.password = self._generate_login_token(service_account=self.cloudsql_connection.login)
+        else:
+            self.user = self.cloudsql_connection.login
+            self.password = self.cloudsql_connection.password
         self.public_ip = self.cloudsql_connection.host
         self.public_port = self.cloudsql_connection.port
         self.ssl_cert = ssl_cert
@@ -856,7 +862,7 @@ class CloudSQLDatabaseHook(BaseHook):
         # Port and socket path and db_hook are automatically generated
         self.sql_proxy_tcp_port = None
         self.sql_proxy_unique_path: str | None = None
-        self.db_hook: PostgresHook | MySqlHook | None = None
+        self.db_hook: BaseHook | None = None
         self.reserved_tcp_socket: socket.socket | None = None
         # Generated based on clock + clock sequence. Unique per host (!).
         # This is important as different hosts share the database
@@ -931,7 +937,9 @@ class CloudSQLDatabaseHook(BaseHook):
             self.log.info("Neither cert path and cert value provided. Nothing to save.")
             return None
 
-        _temp_file = NamedTemporaryFile(mode="w+b", prefix="/tmp/certs/")
+        certs_folder = "/tmp/certs/"
+        Path(certs_folder).mkdir(parents=True, exist_ok=True)
+        _temp_file = NamedTemporaryFile(mode="w+b", prefix=certs_folder)
         if cert_path:
             with open(cert_path, "rb") as cert_file:
                 _temp_file.write(cert_file.read())
@@ -1140,7 +1148,7 @@ class CloudSQLDatabaseHook(BaseHook):
             gcp_conn_id=self.gcp_conn_id,
         )
 
-    def get_database_hook(self, connection: Connection) -> PostgresHook | MySqlHook:
+    def get_database_hook(self, connection: Connection) -> BaseHook:
         """
         Retrieve database hook.
 
@@ -1148,14 +1156,20 @@ class CloudSQLDatabaseHook(BaseHook):
         connects directly to the Google Cloud SQL database.
         """
         if self.database_type == "postgres":
-            db_hook: PostgresHook | MySqlHook = PostgresHook(connection=connection, schema=self.database)
+            from airflow.providers.postgres.hooks.postgres import PostgresHook
+
+            db_hook: BaseHook = PostgresHook(connection=connection, database=self.database)
         else:
+            from airflow.providers.mysql.hooks.mysql import MySqlHook
+
             db_hook = MySqlHook(connection=connection, schema=self.database)
         self.db_hook = db_hook
         return db_hook
 
     def cleanup_database_hook(self) -> None:
         """Clean up database hook after it was used."""
+        from airflow.providers.postgres.hooks.postgres import PostgresHook
+
         if self.database_type == "postgres":
             if not self.db_hook:
                 raise ValueError("The db_hook should be set")
@@ -1181,3 +1195,32 @@ class CloudSQLDatabaseHook(BaseHook):
         if self.reserved_tcp_socket:
             self.reserved_tcp_socket.close()
             self.reserved_tcp_socket = None
+
+    def _get_iam_db_login(self) -> str:
+        """Get an IAM login for Cloud SQL database."""
+        if not self.cloudsql_connection.login:
+            raise AirflowException("The login parameter needs to be set in connection")
+
+        if self.database_type == "postgres":
+            return self.cloudsql_connection.login.split(".gserviceaccount.com")[0]
+        else:
+            return self.cloudsql_connection.login.split("@")[0]
+
+    def _generate_login_token(self, service_account) -> str:
+        """Generate an IAM login token for Cloud SQL and return the token."""
+        cmd = ["gcloud", "sql", "generate-login-token", f"--impersonate-service-account={service_account}"]
+        self.log.info("Executing command: %s", " ".join(shlex.quote(c) for c in cmd))
+        cloud_sql_hook = CloudSQLHook(api_version="v1", gcp_conn_id=self.gcp_conn_id)
+
+        with cloud_sql_hook.provide_authorized_gcloud():
+            proc = subprocess.run(cmd, capture_output=True)
+
+        if proc.returncode != 0:
+            stderr_last_20_lines = "\n".join(proc.stderr.decode().strip().splitlines()[-20:])
+            raise AirflowException(
+                f"Process exited with non-zero exit code. Exit code: {proc.returncode}. Error Details: "
+                f"{stderr_last_20_lines}"
+            )
+
+        auth_token = proc.stdout.decode().strip()
+        return auth_token
