@@ -16,21 +16,21 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery sensors."""
+
 from __future__ import annotations
 
 import warnings
 from datetime import timedelta
 from typing import TYPE_CHECKING, Any, Sequence
 
-from deprecated import deprecated
-
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
 from airflow.providers.google.cloud.triggers.bigquery import (
     BigQueryTableExistenceTrigger,
     BigQueryTablePartitionExistenceTrigger,
 )
+from airflow.providers.google.common.deprecated import deprecated
 from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
@@ -143,15 +143,9 @@ class BigQueryTableExistenceSensor(BaseSensorOperator):
         if event:
             if event["status"] == "success":
                 return event["message"]
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
 
-        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
         message = "No event received in trigger callback"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
         raise AirflowException(message)
 
 
@@ -259,25 +253,16 @@ class BigQueryTablePartitionExistenceSensor(BaseSensorOperator):
             if event["status"] == "success":
                 return event["message"]
 
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
 
-        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
         message = "No event received in trigger callback"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
         raise AirflowException(message)
 
 
 @deprecated(
-    reason=(
-        "Class `BigQueryTableExistenceAsyncSensor` is deprecated and "
-        "will be removed in a future release. "
-        "Please use `BigQueryTableExistenceSensor` and "
-        "set `deferrable` attribute to `True` instead"
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="BigQueryTableExistenceSensor",
+    instructions="Please use BigQueryTableExistenceSensor and set deferrable attribute to True.",
     category=AirflowProviderDeprecationWarning,
 )
 class BigQueryTableExistenceAsyncSensor(BigQueryTableExistenceSensor):
@@ -314,12 +299,9 @@ class BigQueryTableExistenceAsyncSensor(BigQueryTableExistenceSensor):
 
 
 @deprecated(
-    reason=(
-        "Class `BigQueryTableExistencePartitionAsyncSensor` is deprecated and "
-        "will be removed in a future release. "
-        "Please use `BigQueryTablePartitionExistenceSensor` and "
-        "set `deferrable` attribute to `True` instead"
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="BigQueryTablePartitionExistenceSensor",
+    instructions="Please use BigQueryTablePartitionExistenceSensor and set deferrable attribute to True.",
     category=AirflowProviderDeprecationWarning,
 )
 class BigQueryTableExistencePartitionAsyncSensor(BigQueryTablePartitionExistenceSensor):
